@@ -34,46 +34,48 @@ class Instance(_base.Resource):
         router_id='vpc_id')
 
     #: Availability Zone.
-    #: *Type:str*
+    #: *Type:string*
     availability_zone = resource.Body('availability_zone')
     # TODO(not_gtema): extract backup strategy into separate type
     #: Backup Strategy.
     #: *Type: dict*
     backup_strategy = resource.Body('backup_strategy', type=dict)
     #: Specifies the billing information, which is pay-per-use.
-    #: *Type: dict*
+    #: *Type:dict*
     charge_info = resource.Body('charge_info', type=dict)
     #: Parameter configuration ID.
     #: *Type:uuid*
     configuration_id = resource.Body('configuration_id')
     #: Instance created time.
-    #: *Type:str*
+    #: *Type:string*
     created_at = resource.Body('created')
     #: Data store information.
-    #: *Type: dict*
+    #: *Type:dict*
     datastore = resource.Body('datastore', type=dict)
     #: Datastore type information (for querying).
+    #: *Type:string*
     datastore_type = resource.Body('datastore_type')
     #: Disk Encryption Key Id.
-    #: *Type:str*
+    #: *Type:uuid*
     disk_encryption_id = resource.Body('disk_encryption_id')
     #: Flavor ID
     #: *Type:uuid*
     flavor_ref = resource.Body('flavor_ref')
     #: Async job id
+    #: *Type:uuid*
     job_id = resource.Body('job_id')
     #: HighAvailability configuration parameters.
-    #: *Type: dict*
+    #: *Type:dict*
     ha = resource.Body('ha', type=dict)
     #: Maintenance time window.
-    #: *Type:str*
+    #: *Type:string*
     maintenance_window = resource.Body('maintenance_window')
     #: Node information
     #: Indicates the primary/standby DB instance information.
     #: *Type:list*
     nodes = resource.Body('nodes', type=list)
     #: Password of the default user.
-    #: *Type:str*
+    #: *Type:string*
     password = resource.Body('password')
     #: Database listen port number.
     #: *Type:int*
@@ -85,43 +87,53 @@ class Instance(_base.Resource):
     #: *Type:list*
     public_ips = resource.Body('public_ips', type=list)
     #: Region where DB is deployed.
-    #: *Type:str*
+    #: *Type:string*
     region = resource.Body('region')
     #: list of associated DB instances.
     #: *Type:list*
     related_instances = resource.Body('related_instance', type=list)
     #: Specifies the DB instance ID, which is used to create a read replica.
+    #: *Type:uuid*
     replica_of_id = resource.Body('replica_of_id')
     #: Specifies the restoration point for instance recovery.
-    #: *Type: dict*
+    #: *Type:dict*
     restore_point = resource.Body('restore_point', type=dict)
     #: Recovery time period for instance.
-    restore_time = resource.Body('restore_time', type=list)
+    #: *Type:string*
+    restore_time = resource.Body('restore_time')
     #: Neutron router ID.
+    #: *Type:uuid*
     router_id = resource.Body('vpc_id')
     #: Security Group Id.
+    #: *Type:uuid*
     security_group_id = resource.Body('security_group_id')
-    #: Id of net.
+    #: Id of network.
+    #: *Type:uuid*
     network_id = resource.Body('subnet_id')
     #: Instance status.
+    #: *Type:string*
     status = resource.Body('status')
     #: Switch Strategy. The value can be reliability or availability,
     #: indicating the reliability first and availability first, respectively.
-    #: *Type:str*
+    #: *Type:string*
     switch_strategy = resource.Body('switch_strategy')
+    #: Lists the tags and their values attached to the instance.
+    #: *Type:dict*
+    tags = resource.Body('tags', type=dict)
     #: Time Zone.
-    #: *Type:str*
+    #: *Type:string*
     time_zone = resource.Body('time_zone')
     #: Instance type Single/Ha/Replica.,
-    #: *Type:str*
+    #: *Type:string*
     type = resource.Body('type')
     # datastore: Instance updated time.
-    #: *Type:str*
+    #: *Type:string*
     updated_at = resource.Body('updated')
     #: Default user of the DB
+    #: *Type:string*
     user_name = resource.Body('db_user_name')
     #: Volume information
-    #: *Type: dict*
+    #: *Type:dict*
     volume = resource.Body('volume', type=dict)
 
     def _translate_response(self, response, has_body=None, error_message=None):
@@ -197,7 +209,6 @@ class Instance(_base.Resource):
         session = cls._get_session(session)
 
         result = cls._find(session, name_or_id, id=name_or_id, **params)
-
         if not result:
             result = cls._find(session, name_or_id, name=name_or_id, **params)
 
@@ -217,6 +228,16 @@ class Instance(_base.Resource):
         if result is not None:
             return result
 
+    def _action(self, session, request_body):
+        url = utils.urljoin(self.base_path, self.id, 'action')
+        response = session.post(url, json=request_body)
+        exceptions.raise_from_response(response)
+
+    def _tag_action(self, session, request_body):
+        url = utils.urljoin(self.base_path, self.id, 'tags', 'action')
+        response = session.post(url, json=request_body)
+        exceptions.raise_from_response(response)
+
     def fetch(self, session, requires_id=True,
               base_path=None, error_message=None, **params):
         """Get a remote resource based on this instance.
@@ -257,10 +278,10 @@ class Instance(_base.Resource):
         return self.restore_time
 
     def get_instance_configuration(self, session):
-        pass
+        raise NotImplementedError()
 
-    def update_instance_configuration(self, session):
-        pass
+    def update_instance_configuration(self, session, values):
+        raise NotImplementedError()
 
     def restore(self, session, backup=None, restore_time=None):
         """Restore instance from the backup of PIR.
@@ -313,3 +334,71 @@ class Instance(_base.Resource):
         exceptions.raise_from_response(response)
 
         return None
+
+    def get_logs(self, session, log_type, start_date, end_date,
+                 offset, limit, level):
+        """Get instance logs
+
+        :param session: The session to use for making this request.
+            :type session: :class:`~keystoneauth1.adapter.Adapter`
+        :param str log_type: The type of logs to query:
+            'errorlog' or 'slowlog'.
+        :param str start_date: Start date of the of the log query. Format:
+            %Y-%m-%dT%H:%M:%S%z where z is the tzinfo in HHMM format.
+        :param str end_date: End date of the of the log query. Format:
+            %Y-%m-%dT%H:%M:%S%z where z is the tzinfo in HHMM format.
+        :param int offset: .
+        :param int limit: Specifies the number of records on a page. Its value
+            range is from 1 to 100.
+        :param str level: Specifies the log level.
+
+        """
+        url_params = log_type + '?' + '&'.join([
+            'start_date=' + start_date,
+            'end_date=' + end_date,
+            'offset=' + str(offset),
+            'limit=' + str(limit),
+            'level=' + level
+        ])
+        url = utils.urljoin(self.base_path, self.id, url_params)
+        response = session.get(url)
+        exceptions.raise_from_response(response)
+        return response.json()
+
+    def restart(self, session):
+        """Restart the database instance
+        """
+        self._action(session, {"restart": {}})
+
+    def enlarge_volume(self, session, size):
+        """Enlarge the instance volume
+        """
+        self._action(session, {"enlarge_volume": {"size": int(size)}})
+
+    def update_flavor(self, session, spec_code):
+        """Chage the instance's flavor
+        """
+        self._action(session, {"resize_flavor": {"spec_code": spec_code}})
+
+    def add_tag(self, session, key, value):
+        """Add tag to instance
+        """
+        request_body = {
+            "action": "create",
+            "tags": [{
+                "key": key,
+                "value": value
+            }]
+        }
+        self._tag_action(session, request_body)
+
+    def remove_tag(self, session, key):
+        """Remove tag from instance
+        """
+        request_body = {
+            "action": "delete",
+            "tags": [{
+                "key": key
+            }]
+        }
+        self._tag_action(session, request_body)
